<?php

namespace Litecms\Plancategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Plancategory\Models\Plancategory;

class PlancategoryPolicy
{

    /**
     * Determine if the given user can view the plancategory.
     *
     * @param UserPolicy $user
     * @param Plancategory $plancategory
     *
     * @return bool
     */
    public function view(UserPolicy $user, Plancategory $plancategory)
    {
        if ($user->canDo('plancategory.plancategory.view') && $user->isAdmin()) {
            return true;
        }

        return $plancategory->user_id == user_id() && $plancategory->user_type == user_type();
    }

    /**
     * Determine if the given user can create a plancategory.
     *
     * @param UserPolicy $user
     * @param Plancategory $plancategory
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plancategory.plancategory.create');
    }

    /**
     * Determine if the given user can update the given plancategory.
     *
     * @param UserPolicy $user
     * @param Plancategory $plancategory
     *
     * @return bool
     */
    public function update(UserPolicy $user, Plancategory $plancategory)
    {
        if ($user->canDo('plancategory.plancategory.edit') && $user->isAdmin()) {
            return true;
        }

        return $plancategory->user_id == user_id() && $plancategory->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given plancategory.
     *
     * @param UserPolicy $user
     * @param Plancategory $plancategory
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Plancategory $plancategory)
    {
        return $plancategory->user_id == user_id() && $plancategory->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given plancategory.
     *
     * @param UserPolicy $user
     * @param Plancategory $plancategory
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Plancategory $plancategory)
    {
        if ($user->canDo('plancategory.plancategory.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given plancategory.
     *
     * @param UserPolicy $user
     * @param Plancategory $plancategory
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Plancategory $plancategory)
    {
        if ($user->canDo('plancategory.plancategory.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
